# English introduction
text2me —— Send a message to your own phone using Twilio

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 中文介绍
text2me ——通过Twilio发消息给自己手机

- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

# 用法
> 准备一个txt文件，按照以下格式布局：
> 
> 账户SID
> 
> AUTH认证标识
> 
> 发送者手机号（必须加国家号）
> 
> 接收者手机号（必须加国家号）
> 
> `import text2me`
> 
> `text2me.send('消息', '文件路径')`
>
> P.S.:你可能需要霍格沃兹魔法才能正常使用

- - - - - - - - - - - - - - - - - - - - - - - - - - - -
# bug反馈
### 如您在使用中发现任何问题，请访问作者[GitHub](https://github.com/CHUA-X/Text2Me/issues "作者的GitHub")留言反馈，谢谢！